# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, constr
from access_server_connector.models.resource_type import ResourceType
from access_server_connector.models.rule_body import RuleBody

class RulePresetPatchIn(BaseModel):
    """
    RulePresetPatchIn
    """
    name: Optional[constr(strict=True, max_length=128, min_length=1)] = None
    resource_type: Optional[ResourceType] = None
    body: Optional[RuleBody] = None
    expired_message: Optional[StrictStr] = None
    __properties = ["name", "resource_type", "body", "expired_message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RulePresetPatchIn:
        """Create an instance of RulePresetPatchIn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of body
        if self.body:
            _dict['body'] = self.body.to_dict()
        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict['name'] = None

        # set to None if resource_type (nullable) is None
        # and __fields_set__ contains the field
        if self.resource_type is None and "resource_type" in self.__fields_set__:
            _dict['resource_type'] = None

        # set to None if body (nullable) is None
        # and __fields_set__ contains the field
        if self.body is None and "body" in self.__fields_set__:
            _dict['body'] = None

        # set to None if expired_message (nullable) is None
        # and __fields_set__ contains the field
        if self.expired_message is None and "expired_message" in self.__fields_set__:
            _dict['expired_message'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RulePresetPatchIn:
        """Create an instance of RulePresetPatchIn from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RulePresetPatchIn.parse_obj(obj)

        _obj = RulePresetPatchIn.parse_obj({
            "name": obj.get("name"),
            "resource_type": obj.get("resource_type"),
            "body": RuleBody.from_dict(obj.get("body")) if obj.get("body") is not None else None,
            "expired_message": obj.get("expired_message")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_rule_preset_out import WrappedResponseRulePresetOut  # noqa: E501

class TestWrappedResponseRulePresetOut(unittest.TestCase):
    """WrappedResponseRulePresetOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseRulePresetOut:
        """Test WrappedResponseRulePresetOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseRulePresetOut`
        """
        model = WrappedResponseRulePresetOut()  # noqa: E501
        if include_optional:
            return WrappedResponseRulePresetOut(
                done = True,
                result = access_server_connector.models.rule_preset_out.RulePresetOut(
                    id = 56, 
                    name = '', 
                    resource_type = null, 
                    access_mode = 'available', 
                    unlock_delay_ms = 56, 
                    unlock_align_cron = '', 
                    access_duration_ms = 56, 
                    starts_at = 56, 
                    ends_at = 56, 
                    window_cron = '', 
                    window_duration_ms = 56, 
                    timezone = '', 
                    binding = 'single', 
                    expired_message = '', 
                    created_at = 56, 
                    updated_at = 56, )
            )
        else:
            return WrappedResponseRulePresetOut(
                result = access_server_connector.models.rule_preset_out.RulePresetOut(
                    id = 56, 
                    name = '', 
                    resource_type = null, 
                    access_mode = 'available', 
                    unlock_delay_ms = 56, 
                    unlock_align_cron = '', 
                    access_duration_ms = 56, 
                    starts_at = 56, 
                    ends_at = 56, 
                    window_cron = '', 
                    window_duration_ms = 56, 
                    timezone = '', 
                    binding = 'single', 
                    expired_message = '', 
                    created_at = 56, 
                    updated_at = 56, ),
        )
        """

    def testWrappedResponseRulePresetOut(self):
        """Test WrappedResponseRulePresetOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
